@@ -2,13 +2,13 @@
 
 """Bluetooth Low Energy Python3 interface"""
 
-import sys
-import os
-import time
-import subprocess
 import binascii
-import struct
+import os
 import signal
+import struct
+import subprocess
+import sys
+import time
 from queue import Queue, Empty
 from threading import Thread
 
@@ -67,6 +67,7 @@ class BTLEException(Exception):
             if self.emsg:
                 msg = f"{msg}error: {self.emsg}"
             msg = f"{msg})"
+        msg = f"(btle) {self.message}"
         return msg
 
 
@@ -75,7 +76,12 @@ class BTLEInternalError(BTLEException):
         BTLEException.__init__(self, message, rsp)
 
 
-class BTLEDisconnectError(BTLEException):
+class BTLEConnectError(BTLEException):
+    def __init__(self, message, rsp=None):
+        BTLEException.__init__(self, message, rsp)
+
+
+class BTLEConnectTimeout(BTLEException):
     def __init__(self, message, rsp=None):
         BTLEException.__init__(self, message, rsp)
 
@@ -98,7 +104,7 @@ class UUID:
         """
         if isinstance(val, int):
             if (val < 0) or (val > 0xFFFFFFFF):
-                raise ValueError("*** -btle- Short form UUIDs must be in range 0..0xFFFFFFFF")
+                raise ValueError("(btle.py) Short form UUIDs must be in range 0..0xFFFFFFFF")
             val = f"{val:04X}"
         elif isinstance(val, self.__class__):
             val = str(val)
@@ -111,7 +117,9 @@ class UUID:
 
         self.binVal = binascii.a2b_hex(val.encode("utf-8"))
         if len(self.binVal) != 16:
-            raise ValueError(f"*** -btle- UUID must be 16 bytes, got '{val}' (len={len(self.binVal)})")
+            raise ValueError(
+                f"(btle.py) UUID must be 16 bytes, got '{val}' (len={len(self.binVal)})"
+            )
         self.commonName = commonName
 
     def __str__(self):
@@ -149,7 +157,9 @@ class Service:
     def getCharacteristics(self, forUUID=None):
         if not self.chars:  # Unset, or empty
             self.chars = (
-                [] if self.hndEnd <= self.hndStart else self.peripheral.getCharacteristics(self.hndStart, self.hndEnd)
+                []
+                if self.hndEnd <= self.hndStart
+                else self.peripheral.getCharacteristics(self.hndStart, self.hndEnd)
             )
         if forUUID is not None:
             u = UUID(forUUID)
@@ -329,7 +339,7 @@ class Bluepy3Helper:
 
     def _writeCmd(self, cmd):
         if self._helper is None:
-            raise BTLEInternalError("*** -btle- Helper not started (did you call connect()?)")
+            raise BTLEInternalError("Helper not started (did you call connect()?)")
         DBG(f"    -btle- Sent:   {cmd}")
         self._helper.stdin.write(cmd)
         self._helper.stdin.flush()
@@ -339,7 +349,7 @@ class Bluepy3Helper:
         rsp = self._waitResp("mgmt")
         if rsp["code"][0] != "success":
             self._stopHelper()
-            raise BTLEManagementError(f"*** -btle- Failed to execute management command '{cmd}'", rsp)
+            raise BTLEManagementError(f"Failed to execute management command '{cmd}'", rsp)
 
     @staticmethod
     def parseResp(line):
@@ -356,7 +366,7 @@ class Bluepy3Helper:
             elif tval[0] == "b":
                 val = binascii.a2b_hex(tval[1:].encode("utf-8"))
             else:
-                raise BTLEInternalError(f"*** -btle- Cannot understand response value {repr(tval)}")
+                raise BTLEInternalError(f"Cannot understand response value {repr(tval)}")
             if tag not in resp:
                 resp[tag] = [val]
             else:
@@ -366,28 +376,30 @@ class Bluepy3Helper:
     def _waitResp(self, wantType, timeout=BTLE_TIMEOUT):
         while True:
             if self._helper.poll() is not None:
-                raise BTLEInternalError("*** -btle- Helper exited")
+                raise BTLEInternalError("Helper exited")
 
             try:
                 rv = self._lineq.get(timeout=timeout)
             except Empty:
                 DBG("*** -btle- Select timeout")
                 return None
-            dehex_rv = repr(rv).replace("\\x1e", "; ").replace("\\n", "").replace("'", "").strip('"')
+            dehex_rv = (
+                repr(rv).replace("\\x1e", "; ").replace("\\n", "").replace("'", "").strip('"')
+            )
             DBG(f"    -btle- Got:    {dehex_rv}")
             if rv.startswith("#") or rv == "\n" or len(rv) == 0:
                 continue
 
             resp = Bluepy3Helper.parseResp(rv)
             if "rsp" not in resp:
-                raise BTLEInternalError("*** -btle- No response type indicator", resp)
+                raise BTLEInternalError("No response type indicator", resp)
 
             # sometimes devices just keep sending `ntfy`
             if "ntfy" in repr(rv):
                 self._aiti += 1
                 if self._aiti > 3:
                     self._stopHelper()
-                    raise BTLEInternalError("*** -btle- I am not an idiot.", resp)
+                    raise BTLEInternalError("Device keeps repeating itself. Giving up.", resp)
 
             respType = resp["rsp"][0]
 
@@ -403,20 +415,22 @@ class Bluepy3Helper:
             elif respType == "stat":
                 if "state" in resp and len(resp["state"]) > 0 and resp["state"][0] == "disc":
                     self._stopHelper()
-                    raise BTLEDisconnectError("*** -btle- Device disconnected", resp)
+                    raise BTLEConnectError("Device disconnected", resp)
             elif respType == "err":
                 errcode = resp["code"][0]
                 if errcode == "nomgmt":
-                    raise BTLEManagementError("*** -btle- Management not available (permissions problem?)", resp)
+                    raise BTLEManagementError(
+                        "Management not available (permissions problem?)", resp
+                    )
                 elif errcode == "atterr":
-                    raise BTLEGattError("*** -btle- Bluetooth command failed", resp)
+                    raise BTLEGattError("Bluetooth command failed", resp)
                 else:
-                    raise BTLEException(f"*** -btle- Error from bluepy3-helper ({errcode})", resp)
+                    raise BTLEException(f"Error from bluepy3-helper ({errcode})", resp)
             elif respType == "scan":
                 # Scan response when we weren't interested. Ignore it
                 continue
             else:
-                raise BTLEInternalError(f"*** -btle- Unexpected response ({respType})", resp)
+                raise BTLEInternalError(f"Unexpected response ({respType})", resp)
 
     def status(self):
         self._writeCmd("stat\n")
@@ -424,7 +438,9 @@ class Bluepy3Helper:
 
 
 class Peripheral(Bluepy3Helper):
-    def __init__(self, deviceAddr=None, addrType=ADDR_TYPE_PUBLIC, iface=None, timeout=BTLE_TIMEOUT):
+    def __init__(
+        self, deviceAddr=None, addrType=ADDR_TYPE_PUBLIC, iface=None, timeout=BTLE_TIMEOUT
+    ):
         Bluepy3Helper.__init__(self)
         self._serviceMap = None  # Indexed by UUID
         (self.deviceAddr, self.addrType, self.iface) = (None, None, None)
@@ -463,11 +479,13 @@ class Peripheral(Bluepy3Helper):
             return resp
 
     def _connect(self, addr, addrType=ADDR_TYPE_PUBLIC, iface=None, timeout=BTLE_TIMEOUT):
-        max_retries = 10
+        max_retries = 5
         if len(addr.split(":")) != 6:
-            raise ValueError(f"*** -btle- Expected MAC address, got {repr(addr)}")
+            raise ValueError(f"(btle.py) Expected MAC address, got {repr(addr)}")
         if addrType not in (ADDR_TYPE_PUBLIC, ADDR_TYPE_RANDOM):
-            raise ValueError(f"*** -btle- Expected address type public or random, got {addrType}")
+            raise ValueError(
+                f"(btle.py) Expected address type public or random, got {addrType}"
+            )
         self.retries = max_retries
         while self.retries > 0:
             self._startHelper(iface)
@@ -479,8 +497,8 @@ class Peripheral(Bluepy3Helper):
             else:
                 self._writeCmd(f"conn {addr} {addrType}\n")
             rsp = self._getResp("stat", timeout)
-            timeout_exception = BTLEDisconnectError(
-                f" -btle- Timed out while trying to connect to peripheral {addr}, addr type: {addrType}, interface {iface}, timeout={timeout}",
+            timeout_exception = BTLEConnectTimeout(
+                f"Timed out while trying to connect to peripheral {addr}, addr type: {addrType}, interface {iface}, timeout={timeout}",
                 rsp,
             )
             if rsp is None:
@@ -499,8 +517,8 @@ class Peripheral(Bluepy3Helper):
                     DBG(f"*** -btle-  Failed to connect. ({self.retries})")
                     time.sleep(0.5 * (max_retries - self.retries))
                     if self.retries <= 1:
-                        raise BTLEDisconnectError(
-                            f"*** -btle- Failed to connect to peripheral {addr}, addr type: {addrType}, interface {iface}, timeout={timeout}",
+                        raise BTLEConnectError(
+                            f"Failed to connect to peripheral {addr}, addr type: {addrType}, interface {iface}, timeout={timeout}",
                             rsp,
                         )
             self.retries -= 1
@@ -554,7 +572,7 @@ class Peripheral(Bluepy3Helper):
         self._writeCmd(f"svcs {uuid}\n")
         rsp = self._getResp("find")
         if "hstart" not in rsp:
-            raise BTLEGattError(f"*** -btle- Service {uuid.getCommonName()} not found", rsp)
+            raise BTLEGattError(f"Service {uuid.getCommonName()} not found", rsp)
         svc = Service(self, uuid, rsp["hstart"][0], rsp["hend"][0])
 
         if self._serviceMap is None:
@@ -573,15 +591,16 @@ class Peripheral(Bluepy3Helper):
             cmd += f" {UUID(uuid)}"
         self._writeCmd(cmd + "\n")
         rsp = self._getResp("find", timeout)
-        timeout_exception = BTLEDisconnectError(
-            f" -btle- Timed out while trying to get characteristics from peripheral {self.addr}, addr type: {self.addrType}",
+        timeout_exception = BTLEConnectTimeout(
+            f"Timed out while trying to get characteristics from peripheral {self.addr}, addr type: {self.addrType}",
             rsp,
         )
         if rsp is None:
             raise timeout_exception
         nChars = len(rsp["hnd"])
         return [
-            Characteristic(self, rsp["uuid"][i], rsp["hnd"][i], rsp["props"][i], rsp["vhnd"][i]) for i in range(nChars)
+            Characteristic(self, rsp["uuid"][i], rsp["hnd"][i], rsp["props"][i], rsp["vhnd"][i])
+            for i in range(nChars)
         ]
 
     def getDescriptors(self, startHnd=1, endHnd=0xFFFF):
@@ -654,11 +673,13 @@ class Peripheral(Bluepy3Helper):
 
     def setRemoteOOB(self, address, address_type, oob_data, iface=None):
         if len(address.split(":")) != 6:
-            raise ValueError(f"*** -btle- Expected MAC address, got {repr(address)}")
+            raise ValueError(f"(btle.py) Expected MAC address, got {repr(address)}")
         if address_type not in (ADDR_TYPE_PUBLIC, ADDR_TYPE_RANDOM):
-            raise ValueError(f"*** -btle- Expected address type public or random, got {address_type}")
+            raise ValueError(
+                f"(btle.py) Expected address type public or random, got {address_type}"
+            )
         if isinstance(address, ScanEntry):
-            return self._setOOB(address.addr, address.addrType, oob_data, address.iface)
+            return self._setRemoteOOB(address.addr, address.addrType, oob_data, address.iface)
         elif address is not None:
             return self._setRemoteOOB(address, address_type, oob_data, iface)
 
@@ -674,22 +695,37 @@ class Peripheral(Bluepy3Helper):
         if resp is not None:
             data = resp.get("d", [""])[0]
             if data is None:
-                raise BTLEManagementError("*** -btle- Failed to get local OOB data.")
-            if struct.unpack_from("<B", data, 0)[0] != 8 or struct.unpack_from("<B", data, 1)[0] != 0x1B:
-                raise BTLEManagementError("*** -btle- Malformed local OOB data (address).")
+                raise BTLEManagementError("Failed to get local OOB data.")
+            if (
+                struct.unpack_from("<B", data, 0)[0] != 8
+                or struct.unpack_from("<B", data, 1)[0] != 0x1B
+            ):
+                raise BTLEManagementError("Malformed local OOB data (address).")
             address = data[2:8]
             address_type = data[8:9]
-            if struct.unpack_from("<B", data, 9)[0] != 2 or struct.unpack_from("<B", data, 10)[0] != 0x1C:
-                raise BTLEManagementError("*** -btle- Malformed local OOB data (role).")
+            if (
+                struct.unpack_from("<B", data, 9)[0] != 2
+                or struct.unpack_from("<B", data, 10)[0] != 0x1C
+            ):
+                raise BTLEManagementError("Malformed local OOB data (role).")
             role = data[11:12]
-            if struct.unpack_from("<B", data, 12)[0] != 17 or struct.unpack_from("<B", data, 13)[0] != 0x22:
-                raise BTLEManagementError("*** -btle- Malformed local OOB data (confirm).")
+            if (
+                struct.unpack_from("<B", data, 12)[0] != 17
+                or struct.unpack_from("<B", data, 13)[0] != 0x22
+            ):
+                raise BTLEManagementError("Malformed local OOB data (confirm).")
             confirm = data[14:30]
-            if struct.unpack_from("<B", data, 30)[0] != 17 or struct.unpack_from("<B", data, 31)[0] != 0x23:
-                raise BTLEManagementError("*** -btle- Malformed local OOB data (random).")
+            if (
+                struct.unpack_from("<B", data, 30)[0] != 17
+                or struct.unpack_from("<B", data, 31)[0] != 0x23
+            ):
+                raise BTLEManagementError("Malformed local OOB data (random).")
             random = data[32:48]
-            if struct.unpack_from("<B", data, 48)[0] != 2 or struct.unpack_from("<B", data, 49)[0] != 0x1:
-                raise BTLEManagementError("*** -btle- Malformed local OOB data (flags).")
+            if (
+                struct.unpack_from("<B", data, 48)[0] != 2
+                or struct.unpack_from("<B", data, 49)[0] != 0x1
+            ):
+                raise BTLEManagementError("Malformed local OOB data (flags).")
             flags = data[50:51]
             return {
                 "Address": "".join(["%02X" % struct.unpack("<B", c)[0] for c in address]),
@@ -766,7 +802,9 @@ class ScanEntry:
     def _update(self, resp):
         addrType = self.addrTypes.get(resp["type"][0], None)
         if (self.addrType is not None) and (addrType != self.addrType):
-            raise BTLEInternalError(f"*** -btle- Address type changed during scan, for address {self.addr}")
+            raise BTLEInternalError(
+                f"Address type changed during scan, for address {self.addr}"
+            )
         self.addrType = addrType
         self.rssi = -resp["rssi"][0]
         self.connectable = (resp["flag"][0] & 0x4) == 0
@@ -852,7 +890,10 @@ class ScanEntry:
 
     def getScanData(self):
         """Return list of tuples [(tag, description, value)]"""
-        return [(sdid, self.getDescription(sdid), self.getValueText(sdid)) for sdid in self.scanData.keys()]
+        return [
+            (sdid, self.getDescription(sdid), self.getValueText(sdid))
+            for sdid in self.scanData.keys()
+        ]
 
 
 class Scanner(Bluepy3Helper):
@@ -889,7 +930,7 @@ class Scanner(Bluepy3Helper):
 
     def process(self, timeout=10.0):
         if self._helper is None:
-            raise BTLEInternalError("*** -btle- Helper not started (did you call start()?)")
+            raise BTLEInternalError("Helper not started (did you call start()?)")
         start = time.time()
         while True:
             if timeout:
@@ -922,7 +963,7 @@ class Scanner(Bluepy3Helper):
                     self.delegate.handleDiscovery(dev, (dev.updateCount <= 1), isNewData)
 
             else:
-                raise BTLEInternalError(f"*** -btle- Unexpected response: {respType}", resp)
+                raise BTLEInternalError(f"Unexpected response: {respType}", resp)
 
     def getDevices(self):
         return list(self.scanned.values())
@@ -977,7 +1018,7 @@ if __name__ == "__main__":
         sys.exit(f"Usage:\n  {sys.argv[0]} <mac-address> [random]")
 
     if not os.path.isfile(helperExe):
-        raise ImportError(f"*** -btle- Cannot find required executable '{helperExe}'")
+        raise ImportError(f"(btle.py) Cannot find required executable '{helperExe}'")
 
     devAddr = sys.argv[1]
     if len(sys.argv) == 3:
